@@ -2,12 +2,13 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 from builtins import range, str
 from future.utils import PY2
+
 from typing import TYPE_CHECKING
 
 from .exceptions import assert_choice
 
 if TYPE_CHECKING:
-	from typing import Iterable, Iterator
+	from typing import Iterable, Iterator, Union
 
 if PY2:
 	bytes = bytearray
