@@ -1,6 +1,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import bz2, warnings
+import bz2
+import warnings
 from io import TextIOWrapper
 
 """
