@@ -1,17 +1,20 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from builtins import str
-
-import hashlib, zlib, os.path
+import hashlib
+import zlib
 from functools import partial
+from os import fspath
+from pathlib import Path
 from typing import TYPE_CHECKING
 
-from .file import read_file, blockfileiter
+from .file import blockfileiter, read_file
 from .filesystem import scandir_rec
 
 if TYPE_CHECKING:
-	from typing import Callable, Optional, Union, Iterable
+	from typing import Callable, Iterable, Iterator, Optional, Union
+
 	from _hashlib import HASH as Hashobj
+
 	from .filesystem import PathType
 
 FILE_IO_BUFFER_SIZE = 8*1024*1024
@@ -71,22 +74,24 @@ def format_file_hash(hashobj, path):
 	return "{} *{}".format(hashobj.hexdigest(), path)
 
 def hash_dir_str(path, hashcls=hashlib.sha1, include_names=False):
-	# type: (PathType, Callable[[], Hashobj], bool) -> str
+	# type: (PathType, Callable[[], Hashobj], bool) -> Iterator[str]
 
 	""" sorts names naively, e.g. all uppercase chars come before lowercase """
 
 	m = hashcls()
 	for entry in sorted(scandir_rec(path), key=lambda x: x.path):
 		filehash = hash_file(entry.path, hashcls)
-		yield format_file_hash(filehash, entry.path)
+		yield format_file_hash(filehash, fspath(entry))
 		if include_names:
 			m.update(entry.name.encode("utf-8"))
 		m.update(filehash.digest())
-	yield format_file_hash(m, path)
+	yield format_file_hash(m, fspath(path))
 
 ed2k_chunksize = 9728000
 
 def ed2k_hash_file_v1(path):
+	# type: (Path, ) -> str
+
 	""" Returns ed2k hash.
 		This hashing method is used by
 		- MLDonkey
@@ -96,7 +101,7 @@ def ed2k_hash_file_v1(path):
 		This differs from `ed2k_hash_file_v2` only if the file size is a multiple of `ed2k_chunksize`.
 	"""
 
-	if os.path.getsize(path) <= ed2k_chunksize:
+	if path.stat().st_size <= ed2k_chunksize:
 		return md4_hash_data(read_file(path, "rb")).hexdigest()
 
 	ed2k_hashes = (
@@ -106,6 +111,8 @@ def ed2k_hash_file_v1(path):
 	return md4_hash_data(b"".join(ed2k_hashes)).hexdigest()
 
 def ed2k_hash_file_v2(path):
+	# type: (Path, ) -> str
+
 	""" Returns ed2k hash.
 		This hashing method is used by
 		- eMule
@@ -114,7 +121,7 @@ def ed2k_hash_file_v2(path):
 		This differs from `ed2k_hash_file_v1` only if the file size is a multiple of `ed2k_chunksize`.
 	"""
 
-	filesize = os.path.getsize(path)
+	filesize = path.stat().st_size
 	if filesize < ed2k_chunksize:
 		return md4_hash_data(read_file(path, "rb")).hexdigest()
 
