@@ -1,38 +1,44 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-from math import log2, exp
-from itertools import chain
 from collections import Counter
+from itertools import chain
+from math import exp, log2
 from sys import stderr
 from typing import TYPE_CHECKING
 
 import numpy as np
 
-from .numpy import categorical, batchtopk
 from .datastructures import VariableRowMatrix
 from .encoder import BatchLabelEncoder
 from .iter import progress
+from .numpy import batchtopk, categorical
 from .object import cast
 
 if TYPE_CHECKING:
-	from typing import Any, Dict, Iterable, List, Tuple, MutableMapping, Iterator, Union
+	from typing import Any, Dict, Iterable, Iterator, List, MutableMapping, Optional, Tuple, Union
+
+	from .typing import SizedIterable
 
 	RawDocument = List[int]
-	IterableDocuments = Iterable[Iterable[int]]
+	IterableDocuments = Iterable[SizedIterable[int]]
 	TopicsMapping = MutableMapping[Tuple[int, int], int]
 	Indices = Union[slice, np.ndarray]
 
 def top_topics(id2word, term_topic_matrix, num_words=10, decimals=2):
-	# type: (Dict[int, str], float[K, V], int) -> Iterator[List[Tuple[str, float]]]
+	# type: (Dict[int, str], np.ndarray, int, int) -> Iterator[List[Tuple[str, float]]]
+
+	"""
+		term_topic_matrix: float[K, V]
+	"""
 
 	indices_list, probs_list = batchtopk(term_topic_matrix, num_words, reverse=True)
-	np.around(probs_list, decimals=2, out=probs_list)
+	np.around(probs_list, decimals=decimals, out=probs_list)
 
 	for indices, probs in zip(indices_list, probs_list):
 		yield [(id2word[id], prob) for id, prob in zip(indices, probs)]
 
 def format_topics(topics, linesep="\n", tokensep="\t"):
-	# type: (Iterable[List[Tuple[str, float]]], ) -> str
+	# type: (Iterable[List[Tuple[str, float]]], str, str) -> str
 
 	buffer = []
 
@@ -41,7 +47,7 @@ def format_topics(topics, linesep="\n", tokensep="\t"):
 
 	return linesep.join(buffer)
 
-class LDADocument(object):
+class LDADocument(SizedIterable[int]):
 
 	def __init__(self, words):
 		# type: (RawDocument, ) -> None
@@ -65,8 +71,21 @@ class LDADocument(object):
 
 class LDABase(object):
 
+	K: int
+	nmk: np.ndarray
+	nkt: np.ndarray
+	nk: np.ndarray
+	nm: np.ndarray
+
+	α: float
+	β: float
+	αsum: float
+	βsum: float
+
+	docs: List[LDADocument]
+
 	def __init__(self, seed=None):
-		# type: () -> None
+		# type: (Optional[int], ) -> None
 
 		np.seterr(all="raise")
 		np.random.seed(seed)
@@ -114,14 +133,14 @@ class LDABase(object):
 				self.add_counts(m, t, k)
 
 	def calc_probs(self, m, t, k_select=slice(None)):
-		# type: (int, int, Indices) -> float[K]
+		# type: (int, int, Indices) -> np.ndarray
 
 		# notes: np.sum(self.nkt, axis=-1) == self.nk
 		# notes: np.sum(self.nmk[m], axis=-1) == self.nm[m]
 
-		""" This is eq1. in the DC-LDA paper. """
+		""" This is eq1. in the DC-LDA paper.
 
-		""" The α and β terms could be moved to `initialize`.
+			returns: float[K]
 		"""
 
 		""" The full term for left would be:
@@ -155,6 +174,13 @@ class LDABase(object):
 	def initialize(self):
 		# type: () -> None
 
+		""" Set base parameters """
+
+		raise NotImplementedError
+
+	def initialize_docs(self):
+		# type: () -> None
+
 		""" Set parameters based on input docs """
 
 		raise NotImplementedError
@@ -195,14 +221,22 @@ class LDABase(object):
 				print("Step #{}, metric: {}".format(i, self.metric()))
 
 	def theta(self):
-		# type: () -> float[M, K]
+		# type: () -> np.ndarray
+
+		"""
+			returns: float[M, K]
+		"""
 
 		num = self.nmk + self.α # [M, K]
 		denom = self.nm + self.αsum # [M]
 		return num / denom[:,None] # [M, K]
 
 	def phi(self):
-		# type: () -> float[K, V]
+		# type: () -> np.ndarray
+
+		"""
+			returns: float[K, V]
+		"""
 
 		num = self.nkt + self.β # [K, V]
 		denom = self.nk + self.βsum # [K]
@@ -225,19 +259,28 @@ class LDABase(object):
 		return exp(-num / denom)
 
 	def docs2topics(self):
-		# type: () -> int[M]
+		# type: () -> np.ndarray
+
+		"""
+			returns: int[M]
+		"""
 
 		return np.argmax(self.theta(), axis=-1) # [M]
 
-	def print_topics(self, num_words=10):
-		# type: (int, ) -> List[list[Tuple[str, float]]]
+	def print_topics(self, id2word, num_words=10):
+		# type: (Dict[int, str], int) -> None
 
-		topics = top_topics(self.id2word, self.phi(), num_words)
+		topics = top_topics(id2word, self.phi(), num_words)
 		print(format_topics(topics))
 
 	@staticmethod
 	def generate(theta, phi, doc_lens):
-		# type: (float[K, V], float[M, K], Iterable[int]) -> Tuple[dict, dict]
+		# type: (np.ndarray, np.ndarray, Iterable[int]) -> Tuple[dict, dict]
+
+		"""
+			theta: float[K, V]
+			phi: float[M, K]
+		"""
 
 		z = {} # sparse
 		w = {} # sparse
@@ -265,7 +308,7 @@ class LDA(LDABase):
 	"""
 
 	def __init__(self, n_topics, alpha=0.1, beta=0.01, seed=None):
-		# type: (int, float, float) -> None
+		# type: (int, float, float, Optional[int]) -> None
 
 		LDABase.__init__(self, seed)
 
@@ -301,8 +344,8 @@ class LDA(LDABase):
 		self.nmk = np.zeros((self.M, self.K), dtype=self.inttype) # [M, K] document-topic counts
 		self.nm = np.array(list(map(len, self.docs)), dtype=self.inttype) # [M] total document counts, not necessary for sampling, but useful for theta and phi calculation
 
-		# note: VariableRowMatrix() is slower than a dict here for some reason
-		self.topics = {} # `z`, sparse document-word topics matrix (because rows can have different lengths)
+		# note: VariableRowMatrix(0) is slower than a dict here for some reason
+		self.topics = {} # type: TopicsMapping # `z`, sparse document-word topics matrix (because rows can have different lengths)
 
 	def initialize_topics(self):
 		# type: () -> None
@@ -394,13 +437,21 @@ class LDATermWeight(LDABase):
 		self.inttype = np.int32
 
 	def _one(self, docs):
-		# type: (Any, ) -> int[M, V]
+		# type: (Any, ) -> np.ndarray
+
+		"""
+			returns: int[M, V]
+		"""
 
 		# return np.ones((self.M, self.V))
 		return np.broadcast_to(1, (self.M, self.V)) # is this slower for indexing later?
 
 	def _tf(self, docs):
-		# type: (IterableDocuments, ) -> float[M, V]
+		# type: (IterableDocuments, ) -> np.ndarray
+
+		"""
+			returns: float[M, V]
+		"""
 
 		all_counts = Counter(chain.from_iterable(docs))
 		num_counts = sum(all_counts.values())
@@ -411,7 +462,11 @@ class LDATermWeight(LDABase):
 		return np.broadcast_to(tw, (self.M, self.V))
 
 	def _idf(self, docs):
-		# type: (IterableDocuments, ) -> float[M, V]
+		# type: (IterableDocuments, ) -> np.ndarray
+
+		"""
+			returns: float[M, V]
+		"""
 
 		tw = np.zeros((self.V, ), dtype=self.floattype) # [V]
 
@@ -427,7 +482,11 @@ class LDATermWeight(LDABase):
 		raise NotImplementedError
 
 	def _pmi(self, docs):
-		# type: (IterableDocuments, ) -> float[M, V]
+		# type: (IterableDocuments, ) -> np.ndarray
+
+		"""
+			returns: float[M, V]
+		"""
 
 		tw = np.zeros((self.M, self.V), dtype=self.floattype) # [M, V] term weights
 
@@ -442,7 +501,11 @@ class LDATermWeight(LDABase):
 		return tw
 
 	def _rand(self, docs):
-		# type: (Any, ) -> float[M, V]
+		# type: (Any, ) -> np.ndarray
+
+		"""
+			returns: float[M, V]
+		"""
 
 		return np.random.uniform(0, 1, (self.M, self.V)).astype(self.floattype)
 
@@ -486,7 +549,7 @@ class LDATermWeight(LDABase):
 		#self.nmkt = np.zeros((self.M, self.K, self.V), dtype=self.inttype)
 		self.wmk = np.zeros((self.M, self.K), dtype=self.floattype) # [M, K] weights, same as np.sum(nmkt, axis=-1)
 
-		self.topics = VariableRowMatrix() # [M, Variable] `z`, sparse document-word topics matrix
+		self.topics = VariableRowMatrix(0) # type: VariableRowMatrix[int] # [M, Variable] `z`, sparse document-word topics matrix
 
 	def initialize_topics(self):
 		# type: () -> None
@@ -496,7 +559,11 @@ class LDATermWeight(LDABase):
 		self._initialize_topics(self.docs, self.topics)
 
 	def calc_probs(self, m, t):
-		# type: (int, int) -> float[K]
+		# type: (int, int) -> np.ndarray
+
+		"""
+			returns: float[K]
+		"""
 
 		# here using global weights works
 		#wmk = np.sum(self.tw[m, :][None, :] * self.nmkt[m], axis=-1, dtype=self.floattype)
@@ -596,7 +663,11 @@ class LDAInfer(LDA):
 		self.docs = []
 
 	def calc_probs(self, m, t, k_select=slice(None)):
-		# type: (int, int, Indices) -> float[K]
+		# type: (int, int, Indices) -> np.ndarray
+
+		"""
+			returns: float[K]
+		"""
 
 		left = (self.nmk[m, k_select] + self.α) # [K]
 		num = (self.nkt[k_select, t] + self.nkt_old[k_select, t] + self.β) # [K]
