@@ -1,6 +1,8 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 
-import os, fcntl, signal
+import fcntl
+import os
+import signal
 from typing import TYPE_CHECKING
 
 from .os_shared import _usagetuple
