@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING
 from .func import identity
 
 if TYPE_CHECKING:
-	from typing import Any, Sequence, Callable, TypeVar
+	from typing import Any, Callable, Optional, Sequence, TypeVar
 	T = TypeVar("T")
 	U = TypeVar("U")
 
@@ -28,7 +28,7 @@ def make_binary_search(target):
 	return binary_search_func
 
 def make_binary_search_sequence(seq, target, key=None):
-	# type: (Sequence, Any) -> Callable[[int], BisectRetVal]
+	# type: (Sequence, Any, Optional[Callable]) -> Callable[[int], BisectRetVal]
 
 	key = key or identity
 
