@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 from builtins import chr, map, range
 
 from collections import defaultdict
+from pathlib import Path
 from sys import maxunicode
 from tempfile import gettempdir
 from unicodedata import category
@@ -10,7 +11,7 @@ from unicodedata import category
 from .pickle import cache  # nosec
 
 
-@cache(gettempdir() + "/unicode_categories.{ppv}.pkl", ignoreargs=True)
+@cache(Path(gettempdir() + "/unicode_categories.{ppv}.pkl"), ignoreargs=True)
 def unicode_categories():
 	unicode_categories = defaultdict(set)
 	for c in map(chr, range(maxunicode + 1)):
