@@ -9,9 +9,12 @@ from .compat import FileExistsError
 from .compat.os import PathLike, fspath
 
 if TYPE_CHECKING:
-	from typing import Any, Union, Iterator, Tuple, Sequence
+	from typing import Any, Iterator, Sequence, Tuple, Union
+
 	import numpy as np
+
 	from av import VideoFrame
+
 	from .compat.pathlib import Path
 	WsgiApp = Any
 
@@ -138,7 +141,7 @@ class CvVideo(VideoBase):
 		return offset / self.meta["fps"]
 
 	def _get_frame(self, offset, native=False):
-		# type: (int, ) -> Tuple[float, np.ndarray]
+		# type: (int, bool) -> Tuple[float, np.ndarray]
 
 		self.cap.set(self.cv2.CAP_PROP_POS_FRAMES, offset)
 
